@@ -258,14 +258,14 @@ class Artifacts:
 
     # Artifact 객체를 기반으로 Artifact에 등록된 모든 엔트리의 다운로드 수행
     def download(self) -> str:
-        local_root_path = self.get_download_dir()
+        local_root_path = self.get_download_dir(with_repo_tag=False)
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for idx, entry in enumerate(self.entry_list):
             entry.download(local_root_path, self.id, self.run.team_name,
                            self.exp_name if self.exp_name else self.run.exp_name,
                            self.name, self.type,
                            self.versioning, idx, total_file_count=len(self.entry_list))
-        return local_root_path
+        return self.get_download_dir(with_repo_tag=True)
 
     def get_download_dir(self, with_repo_tag: bool = True):
         # ./deepdriver/artifact/{artifact_id}/{tag} 폴더가 생성된다
